@@ -1,5 +1,6 @@
-from ._claude_code.claude_code import ClaudeCodeOptions, claude_code
-from ._tools.download import download_agent_binary
+from ._claude_code.claude_code import claude_code
+from ._codex_cli.codex_cli import codex_cli
+from ._tools.download import AgentBinary, cached_agent_binaries, download_agent_binary
 from ._util.sandbox import SandboxPlatform
 
 try:
@@ -10,8 +11,10 @@ except ImportError:
 
 __all__ = [
     "claude_code",
-    "ClaudeCodeOptions",
+    "codex_cli",
     "download_agent_binary",
+    "cached_agent_binaries",
+    "AgentBinary",
     "SandboxPlatform",
     "__version__",
 ]
